@@ -4,7 +4,7 @@
 #________________________________
 "A2.simu" <- function()
 {
-	if(!require(tcltk)) stop("package tcltk is required")
+	# if(!require(tcltk)) stop("package tcltk is required")
 	tclRequire("Tktable")
 	#fonts definition
 	font0 <- tkfont.create(family="times",size=35,weight="bold",slant="italic")
