@@ -1,8 +1,8 @@
 "simPCR2TK" <- function()
 {
-	if(!require(tcltk)) stop("package tcltk is required")
-	if(!require(tkrplot)) stop("package tkrplot is required")
-	tclRequire("Tktable")
+	# if(!require(tcltk)) stop("package tcltk is required")
+	# if(!require(tkrplot)) stop("package tkrplot is required")
+	# tclRequire("Tktable")
 	tclRequire("Tktable")
 	font0 <- tkfont.create(family="courrier",size=35,weight="bold",slant="italic")
 	font1<-tkfont.create(family="times",size=14,weight="bold")#,slant="italic")
